'''
Erdbebenexport... von Zoredh mal eben auf die Schnelle für Hendi zusammengeklöppelt...

Auszug aus der Doku zum Input-Dateiformat:

Table 7. WID2 Line Format
Position Name Format Description
1-4 “WID2” a4 Must be “WID2”
6-15 Date i4,a1,i2,a1,i2 Date of the first sample (yyyy/mm/dd)
17-28 Time i2,a1,i2,a1,f6.3 Time of the first sample (hh:mm:ss.sss)
30-34 Station a5 Station code
36-38 Channel a3 FDSN channel code
40-43 Auxid a4 Auxiliary identification code
45-47 Sub_format a3 “INT”, “CMn”, or “AUx”
    INT is free format integers as ASCII characters;
    “CM” denotes compressed data, and n is
    either 6 (6-bit compression), or 8 (8-bit binary compression)
    “AU” signifies authentication and x is T (uncompressed binary integers), 
    6 (6-bit compression), or 8 (8-bit binary compression)
49-56 Samps i8 Number of samples
58-68 Samprate f11.6 Data sampling rate (Hz)
70-79 Calib e10.2 Calibration factor; i.e., the ground motion in
    nanometers per digital count at calibration period (calper)
81-87 Calper f7.3 Calibration reference period; i.e., the period in
    seconds at which calib is valid; calper should
    be near the flat part of the response curve. (in most cases, 1 sec)
89-94 Instype a6 Instrument type (from Table 8)
96-100 Hang f5.1 Horizontal orientation of sensor, measured in
    positive degrees clockwise from North (-1.0 if vertical)
102-105 Vang f4.1 Vertical orientation of sensor, measured in
    degrees from vertical (90.0 if horizontal)
'''

import sys
from datetime import datetime
from datetime import timedelta
from time import mktime

# Writeflag ist 0, wenn noch nichts zu tun ist, 1 Wenn wir im WID2 sind, und 2, wenn wir im Datenblock sind
writeflag = 0
delimiter = ","

# Den Dateinamen muss man schon angeben
if len(sys.argv) < 2:
    print("Syntax: "+ sys.argv[0]+" dateiname")
    exit(1)

with open(sys.argv[1], 'r', encoding='utf-8') as eingabedatei:
    while True:
        # lese eine Zeile bis nix mehr da ist
        zeile = eingabedatei.readline()
        if not zeile: 
            break
       
        # die ersten 4 Zeichen sind der Satztyp
        satztyp = zeile[:4]
        
        # wenn Satztyp="WID2" dann öffne neue CSV-Datei
        if satztyp == "WID2":
            startdate = zeile[5:15]
            starttime = zeile[16:28].replace(" ","0")
            starttimestamp = datetime.strptime(startdate + " " + starttime, '%Y/%m/%d %H:%M:%S.%f')
            timestamp = starttimestamp
            station = zeile[29:34]
            channel = zeile[35:38]
            auxid = zeile[39:43]
            subformat = zeile[44:47]
            samps = zeile[48:56]
            samprate = zeile[57:68]
            # der Rest ist mir erstmal Wurscht
            writeflag = 1
            concat=station + "-" + channel + "-" + startdate.replace("/","-") + "-" + starttime.replace(":","-")
            csvname = concat.replace(" ","").replace(".","-") + ".csv"
            csv = open(csvname,"w")
        elif satztyp == "STA2":
            # ignoriere ich erstmal, weil nicht immer gefüllt
            pass
        elif satztyp == "DAT2":
            # ok, ab jetzt kommen erstmal Daten - die interessieren aber nur, wenn es WID2 ist
            if writeflag > 0:
                writeflag = 2
        elif satztyp == "CHK2" and writeflag > 0:
            # Checksumme wird erstmal ignoriert aber die CSV-Datei wird geschlossen und writeflag wird zurückgesetzt
            writeflag = 0
            csv.close
        elif satztyp == "    " and writeflag > 1:
            #erst jetzt (wir sind im richtigen Datenblock) dann schreiben wir wirklich Daten raus
            
            # Hendi wollte dann doch lieber Unix Epoch mit Nachkomma-Millisekunden
            # zeit=timestamp.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3]
            zeit = str(mktime(timestamp.timetuple()))[:-1]
            ms = timestamp.strftime("%f")[:-3]
            csv.write( zeit + ms + delimiter + zeile.strip()+"\n")
            # wir berechnen anschließend den Timestamp neu
            milliseconds = timedelta(microseconds=(1000000 / float(samprate)))
            timestamp += milliseconds
